@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2013 Lawrence Murray
+ * Copyright (C) 2007-2014 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -13,38 +13,40 @@
 #ifndef INDII_CLUSTER_EUCLIDEANDISTANCE_HPP
 #define INDII_CLUSTER_EUCLIDEANDISTANCE_HPP
 
-#include "ClusterVector.hpp"
-
 namespace indii {
 /**
  * Euclidean distance.
  *
- * @tparam T Datum element type.
+ * @tparam T Element type.
+ * @tparam N Vector size.
  */
-template<class T = float>
+template<class T1 = float, class T2 = float>
 class EuclideanDistance {
 public:
+  typedef T1 value_type;
+  typedef T2 distance_type;
+
+  /**
+   * Preprocess point.
+   *
+   * @param x Point.
+   */
+  static void prepare(T1& x) {
+    //
+  }
+
   /**
    * Calculate distance.
    *
    * @param x1 First point.
-   * @param x2 Second point, should have same size as first.
+   * @param x2 Second point.
    *
    * @return %Distance between the two points.
    */
-  static T distance(const typename ClusterVector<T>::type& x1,
-      const typename ClusterVector<T>::type& x2);
-
+  static T2 distance(const T1 x1, const T1 x2) {
+    return std::fabs(x2 - x1);
+  }
 };
 }
 
-T indii::EuclideanDistance::distance(
-    const typename ClusterVector<T>::type& x1,
-    const typename ClusterVector<T>::type& x2) {
-  /* pre-condition */
-  assert (x1.size() == x2.size());
-
-  return boost::numeric::ublas::norm_2(x2 - x1);
-}
-
 #endif
