@@ -32,7 +32,7 @@ public:
    *
    * @param seed Random number seed.
    */
-  KMeansClusterer(const unsigned seed);
+  KMeansClusterer(const int seed);
 
   /**
    * Cluster data. Continues until convergence or a maximum number of
@@ -134,7 +134,7 @@ private:
 }
 
 template<class D>
-indii::KMeansClusterer<D>::KMeansClusterer(const unsigned seed) {
+indii::KMeansClusterer<D>::KMeansClusterer(const int seed) {
   rng.seed(seed);
 }
 
@@ -167,10 +167,10 @@ void indii::KMeansClusterer<D>::init(const V1& data, V2& ks, V3& cs) {
       dist);
   int i, k;
 
-  for (k = 0; k < cs.size(); ++k) {
+  for (k = 0; k < (int)cs.size(); ++k) {
     cs[k] = 0;
   }
-  for (i = 0; i < data.size(); ++i) {
+  for (i = 0; i < (int)data.size(); ++i) {
     k = rc();
     ks[i] = k;
     ++cs[k];
@@ -188,7 +188,7 @@ void indii::KMeansClusterer<D>::update(const V1& data, const V2& ks, V3& mus,
   std::vector<bool> first(mus.size(), true);
   int i, k;
 
-  for (i = 0; i < data.size(); ++i) {
+  for (i = 0; i < (int)data.size(); ++i) {
     k = ks[i];
     if (first[k]) {
       mus[k] = data[i];
@@ -197,7 +197,7 @@ void indii::KMeansClusterer<D>::update(const V1& data, const V2& ks, V3& mus,
       mus[k] += data[i];
     }
   }
-  for (k = 0; k < mus.size(); ++k) {
+  for (k = 0; k < (int)mus.size(); ++k) {
     mus[k] /= cs[k];
     D::prepare(mus[k]);
   }
@@ -217,7 +217,7 @@ int indii::KMeansClusterer<D>::assign(const T1& x, V1& ds, V2& mus) {
   d = D::distance(x, mus[0]);
   dmin = d;
   ds[k] = d;
-  for (k = 1; k < mus.size(); ++k) {
+  for (k = 1; k < (int)mus.size(); ++k) {
     d = D::distance(x, mus[k]);
     if (d < dmin) {
       kmin = k;
@@ -243,10 +243,10 @@ int indii::KMeansClusterer<D>::assign(const V1& data, V2& ks, V3& ds,
   int k, kmin;
   T3 d, dmin;
 
-  for (i = 0; i < data.size(); ++i) {
+  for (i = 0; i < (int)data.size(); ++i) {
     kmin = 0;
     dmin = D::distance(data[i], mus[0]);
-    for (k = 1; k < mus.size(); ++k) {
+    for (k = 1; k < (int)mus.size(); ++k) {
       d = D::distance(data[i], mus[k]);
       if (d < dmin) {
         kmin = k;
