@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2013 Lawrence Murray
+ * Copyright (C) 2007-20153 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -12,7 +12,6 @@
  */
 #include "App.hpp"
 
-#include "Registration.hpp"
 #include "About.hpp"
 #include "Help.hpp"
 #include "OpenRecentMenu.hpp"
@@ -20,6 +19,7 @@
 #include "../image/FileImageResource.hpp"
 #include "../images/indii.hpp"
 #include "../../gnome/gnome.hpp"
+#include "../../social/social.hpp"
 #include "../meta.hpp"
 #include "../image/ImageManipulation.hpp"
 
@@ -40,8 +40,8 @@ App::App() : window(NULL), haveFile(false) {
 void App::MacOpenFiles(const wxArrayString& fileNames) {
   wxLogNull logNo;
   if (window != NULL) {
-    unsigned i;
-    for (i = 0; i < fileNames.GetCount(); ++i) {
+    int i;
+    for (i = 0; i < (int)fileNames.GetCount(); ++i) {
       if (wxImage::CanRead(fileNames[i])) {
         window->openAndAdd(fileNames[i]);
       } else {
@@ -88,6 +88,7 @@ int App::OnRun() {
   wxInitAllImageHandlers();
   indii_initialize_images();
   gnome_initialize_images();
+  social_initialize_images();
   
   #ifdef __WXOSX__
   wxApp::SetExitOnFrameDelete(false);
@@ -108,9 +109,6 @@ int App::OnRun() {
   wxMenu* mnHelp = new wxMenu();
   mnHelp->Append(wxID_HELP, _("&Help\tCtrl-?"));
   mnHelp->Append(wxID_ABOUT);
-  if (!Components::isActivated(Components::APP)) {
-    mnHelp->Append(ID_BUT_REGISTER, _("Register"));
-  }
   
   mbMenu->Append(mnFile, _("&File"));
   mbMenu->Append(mnHelp, _("&Help"));
@@ -136,29 +134,17 @@ int App::OnRun() {
   }
 
   if (!Components::isActivated(Components::APP)) {
-    if (!Components::isTrial(Components::APP)) {
-      Registration* dlgRegister = new Registration(window, Components::APP);
-      dlgRegister->Centre();
-      if (dlgRegister->ShowModal() != wxID_OK) {
-        dlgRegister->Destroy();
-        window->Close(true);
-        window = NULL;
-        return false;
-      } else {
-        dlgRegister->Destroy();
-        return wxApp::OnRun();
-      }
-    } else if (Components::daysLeft() <= Components::maxDays()/3) {
-      Registration* dlgRegister = new Registration(window, Components::APP);
-      dlgRegister->Centre();
-      dlgRegister->ShowModal();
-      dlgRegister->Destroy();
-      return wxApp::OnRun();
-    } else {
-      return wxApp::OnRun();
-    }
-  } else {
+    About* dlgAbout = new About(window, Components::APP);
+    dlgAbout->Centre();
+    dlgAbout->ShowModal();
+    dlgAbout->Destroy();
+  }
+  if (Components::isActivated(Components::APP) || Components::isTrial(Components::APP)) {
     return wxApp::OnRun();
+  } else {
+    window->Close(true);
+    window = NULL;
+    return false;
   }
 }
 
@@ -240,22 +226,7 @@ void App::OnOpenRecent(wxCommandEvent& evt) {
 }
 
 void App::OnButtonAbout(wxCommandEvent& evt) {
-  showAboutDialog();
-}
-
-void App::OnButtonRegister(wxCommandEvent& evt) {
-  if (window == NULL) {
-    if (Components::isActivated(Components::APP)) {
-      wxMessageBox(_("Your " PACKAGE_NAME " app is already registered."), _("Already registered"), wxICON_INFORMATION);
-    } else {
-      Registration* dlgRegister = new Registration(NULL, Components::APP);
-      dlgRegister->Centre();
-      dlgRegister->ShowModal();
-      dlgRegister->Destroy();
-    }
-  } else {
-    window->OnButtonRegister(evt);
-  }
+  showAboutDialog(window, Components::APP);
 }
 
 void App::OnButtonHelp(wxCommandEvent& evt) {
@@ -288,7 +259,6 @@ BEGIN_EVENT_TABLE(App, wxApp)
 EVT_MENU(wxID_OPEN, App::OnButtonOpen)
 EVT_MENU(wxID_ABOUT, App::OnButtonAbout)
 EVT_MENU(wxID_HELP, App::OnButtonHelp)
-EVT_MENU(ID_BUT_REGISTER, App::OnButtonRegister)
 EVT_MENU(wxID_EXIT, App::OnButtonExit)
 
 EVT_MENU(300, App::OnOpenRecent)
