@@ -61,7 +61,7 @@ void Document::save() {
 
   wxImage img(res->getWidth(), res->getHeight());
   model->calcFg(1, img);
-  img.SetOption(wxIMAGE_OPTION_QUALITY, 95);
+  img.SetOption(wxIMAGE_OPTION_QUALITY, 90);
   wxLogNull logNo;
   isSaved = img.SaveFile(path);
   if (!isSaved) {
@@ -83,10 +83,18 @@ void Document::saveAs() {
     savePath = wxStandardPaths::Get().GetDocumentsDir();
   }
 
+  #if defined(MAC_APP_STORE)
+  wxString defaultExt = _(".jpg");
+  wxString defaultWildcards = wxFileSelectorDefaultWildcardStr;
+  #else
+  wxString defaultExt = _(".png");
+  wxString defaultWildcards = wildcards(true);
+  #endif
+  
   #if defined(__WXGTK__) || defined(MAC_APP_STORE)
-  wxString defaultName(_("image.png"));
+  wxString defaultName(_("image") + defaultExt);
   if (havePath) {
-    defaultName = wxFileName(path).GetName() + _(".png");
+    defaultName = wxFileName(path).GetName() + defaultExt;
   }
   #else
   wxString defaultName(_("image"));
@@ -96,7 +104,7 @@ void Document::saveAs() {
   #endif
 
   wxString path = wxFileSelector(wxFileSelectorPromptStr, savePath,
-      defaultName, _("png"), wildcards(true),
+      defaultName, defaultExt, defaultWildcards,
       wxFD_SAVE|wxFD_OVERWRITE_PROMPT, this);
   if (!path.empty()) {
     wxFileName file(path);
