@@ -55,7 +55,7 @@ private:
 	/**
    * Maximum number of files in list.
    */
-  static const unsigned MAX_FILES = 8;
+  static const int MAX_FILES = 8;
 
   /*
    * Control ids.
