@@ -12,9 +12,7 @@
  */
 #include "Window.hpp"
 
-#include "About.hpp"
 #include "Help.hpp"
-#include "Registration.hpp"
 #include "OpenRecentMenu.hpp"
 #include "WindowMenu.hpp"
 #include "../reg/Components.hpp"
@@ -46,6 +44,7 @@ Window::Window(wxWindow* parent, const Mode mode, WindowObserver* obs) :
     main(NULL), notebook(NULL), doc(NULL), infoBar(NULL) {
   main = new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL|wxBORDER_NONE);
   infoBar = new InfoBar(this);
+  dlgAbout = new About(this, mode == STANDALONE ? Components::APP : Components::PLUGIN);
   if (mode == STANDALONE) {
     notebook = new wxAuiNotebook(main, wxID_ANY, wxDefaultPosition,
         wxDefaultSize, wxAUI_NB_DEFAULT_STYLE|wxBORDER_NONE);
@@ -312,7 +311,7 @@ void Window::OnButtonCancel(wxCommandEvent& evt) {
 }
 
 void Window::OnButtonAbout(wxCommandEvent& evt) {
-  showAboutDialog(this);
+  dlgAbout->ShowModal();
 }
 
 void Window::OnButtonDefault(wxCommandEvent& evt) {
@@ -365,19 +364,6 @@ void Window::OnButZoomFit(wxCommandEvent& evt) {
   doc->getPreviewPane()->getPreviewImage()->zoomFit();
 }
 
-void Window::OnButtonRegister(wxCommandEvent& evt) {
-  if (mode == EMBED && Components::isActivated(Components::PLUGIN)) {
-    wxMessageBox(_("Your " PACKAGE_NAME " plugin is already registered."), _("Already registered"), wxICON_INFORMATION);
-  } else if (mode == STANDALONE && Components::isActivated(Components::APP)) {
-    wxMessageBox(_("Your " PACKAGE_NAME " app is already registered."), _("Already registered"), wxICON_INFORMATION);
-  } else {
-    Registration* dlgRegister = new Registration(this, (mode == EMBED) ? Components::PLUGIN : Components::APP);
-    dlgRegister->Centre();
-    dlgRegister->ShowModal();
-    dlgRegister->Destroy();
-  }
-}
-
 void Window::OnButtonWindow(wxCommandEvent& evt) {
   mnPopupWindow->update();
   this->PopupMenu(mnPopupWindow);
@@ -500,10 +486,6 @@ void Window::init(Document* doc) {
     mnHelp->Append(wxID_HELP);
     #endif
     mnHelp->Append(wxID_ABOUT);
-    if ((mode == EMBED && !Components::isActivated(Components::PLUGIN)) ||
-        (mode == STANDALONE && !Components::isActivated(Components::APP))) {
-     mnHelp->Append(ID_BUT_REGISTER, _("&Register"));
-    }
 
     mbMenu->Append(mnEdit, _("&Edit"));
     mbMenu->Append(mnView, _("&View"));
@@ -515,9 +497,7 @@ void Window::init(Document* doc) {
   mnPopupWindow = new WindowMenu(this);
 
   /* toolbar */
-  #ifndef __WXGTK__
   gnome_scale_images(this->GetContentScaleFactor());
-  #endif
   wxToolBar* tbTop = this->CreateToolBar(wxNO_BORDER|wxTB_FLAT|wxTB_HORIZONTAL);
   tbTop->SetToolBitmapSize(wxSize(32,32));
   if (mode == STANDALONE) {
@@ -550,13 +530,7 @@ void Window::init(Document* doc) {
   #else
   tbTop->AddTool(wxID_HELP, _("Help"), *_img_gnome_help_browser, _("Help"));
   #endif
-  if (mode == EMBED) {
-    tbTop->AddTool(wxID_ABOUT, _("About"), *_img_gnome_dialog_information, _("About"));
-  }
-  if ((mode == STANDALONE && !Components::isActivated(Components::APP)) ||
-      (mode == EMBED && !Components::isActivated(Components::PLUGIN))) {
-    tbTop->AddTool(ID_BUT_REGISTER, _("Register"), *_img_gnome_emblem_web, _("Register"));
-  }
+  tbTop->AddTool(wxID_ABOUT, _("About"), *_img_gnome_dialog_information, _("About"));
   #ifdef __WXOSX__
   //if (mode != EMBED) {
     #ifndef WX_28
@@ -803,7 +777,6 @@ EVT_TOOL(wxID_ZOOM_FIT, Window::OnButZoomFit)
 EVT_TOOL(ID_BUT_DEFAULT, Window::OnButtonDefault)
 EVT_TOOL(wxID_ABOUT, Window::OnButtonAbout)
 EVT_TOOL(wxID_HELP, Window::OnButtonHelp)
-EVT_TOOL(ID_BUT_REGISTER, Window::OnButtonRegister)
 EVT_TOOL(ID_BUT_OVERLAY, Window::OnButtonOverlay)
 EVT_TOOL(ID_BUT_WINDOW, Window::OnButtonWindow)
 
@@ -820,7 +793,6 @@ EVT_MENU(ID_BUT_OVERLAY, Window::OnButtonOverlay)
 EVT_MENU(ID_BUT_DEFAULT, Window::OnButtonDefault)
 EVT_MENU(wxID_ABOUT, Window::OnButtonAbout)
 EVT_MENU(wxID_HELP, Window::OnButtonHelp)
-EVT_MENU(ID_BUT_REGISTER, Window::OnButtonRegister)
 
 EVT_BUTTON(wxID_OK, Window::OnButtonOk)
 EVT_BUTTON(wxID_CANCEL, Window::OnButtonCancel)
