@@ -224,7 +224,7 @@ inline void indii::ColourSpace::hsl2rgb(const hsl_t& hsl, rgb_t& rgb) {
   } else {
     k2 = (s - 1.0f) / (s + 1.0f);
     switch (static_cast<unsigned char>(6.0f*h)) {
-    case 0:
+    case 0: case 6:
       // r > g > b
       k1 = 6.0f*h;
       k3 = k1 + k2 * (k1 - 1.0f);
