@@ -1,4 +1,4 @@
-/**
+ /**
  * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -35,7 +35,7 @@ public:
    * @param img Existing image.
    * @param scale Inverse scale of the new image.
    */
-  Image(const Image& img, const float scale = 1);
+  Image(const Image& img, const float scale = 1.0f);
 
   /**
    * Width of image.
@@ -55,11 +55,11 @@ public:
 }
 
 inline int indii::Image::getWidth() const {
-  return r.size2();
+  return static_cast<int>(r.size2());
 }
 
 inline int indii::Image::getHeight() const {
-  return r.size1();
+  return static_cast<int>(r.size1());
 }
 
 #endif
