@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2013 Lawrence Murray
+ * Copyright (C) 2007-2015 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -19,7 +19,12 @@
 #endif
 
 extern void indii_initialize_images(void);
+extern wxBitmap* indii_retinize(wxBitmap* bmp);
+extern void indii_scale_images(const double contentScale = 1.0);
 
 extern wxBitmap *_img_indii_stipple;
+extern wxBitmap *_img_indii_splash;
+extern wxBitmap *_img_indii_splash_32;
+extern wxBitmap *_img_indii_splash_64;
 
 #endif
