@@ -22,7 +22,7 @@
 
 using namespace indii;
 
-SpectrumImage::SpectrumImage(wxWindow *parent, const unsigned int cluster,
+SpectrumImage::SpectrumImage(wxWindow *parent, const int cluster,
     const Type type) :
     wxPanel(parent), model(NULL), cluster(cluster), type(type),
     fg(ICON_WIDTH,ICON_HEIGHT) {
@@ -54,7 +54,7 @@ void SpectrumImage::notifyNumClustersChange() {
   }
 }
 
-void SpectrumImage::notifyClusterChange(const unsigned int i) {
+void SpectrumImage::notifyClusterChange(const int i) {
   //
 }
 
