@@ -20,7 +20,7 @@ using namespace indii;
 #define SPOW 1.0f
 #define SLIDER_RES 4096.0f
 
-ThumbHSL::ThumbHSL(wxWindow *parent, const unsigned int cluster) :
+ThumbHSL::ThumbHSL(wxWindow *parent, const int cluster) :
     wxPanel(parent), model(NULL), cluster(cluster) {
   static const int PADDING = 4;
 
@@ -66,8 +66,8 @@ ThumbHSL::ThumbHSL(wxWindow *parent, const unsigned int cluster) :
   //sizer->SetFlexibleDirection(wxHORIZONTAL);
   //sizer->AddGrowableCol(2);
   SetSizerAndFit(sizer);
-  //unsigned naturalWidth = this->GetSize().GetWidth();
-  //unsigned naturalHeight = this->GetSize().GetHeight();
+  //int naturalWidth = this->GetSize().GetWidth();
+  //int naturalHeight = this->GetSize().GetHeight();
   //SetMinSize(wxSize(naturalWidth, naturalHeight));
   //SetBestSize(wxSize(naturalWidth, naturalHeight));
 }
@@ -124,14 +124,14 @@ void ThumbHSL::notifySaturationSoftnessChange() {
 //  }
 }
 
-void ThumbHSL::notifyClusterChange(const unsigned int i) {
+void ThumbHSL::notifyClusterChange(const int i) {
   notifyHueChange(i);
   notifySatChange(i);
   notifyLightChange(i);
   notifyAlphaChange(i);
 }
 
-void ThumbHSL::notifyHueChange(const unsigned i) {
+void ThumbHSL::notifyHueChange(const int i) {
   if (i == cluster) {
     int val = intround(model->getHue(cluster) * SLIDER_RES * 2.0f);
     if (slideH->GetValue() != val) {
@@ -140,7 +140,7 @@ void ThumbHSL::notifyHueChange(const unsigned i) {
   }
 }
 
-void ThumbHSL::notifySatChange(const unsigned i) {
+void ThumbHSL::notifySatChange(const int i) {
   if (i == cluster) {
     float s = model->getSat(cluster);
     float sign = (s < 0.0f) ? -1.0f : 1.0f;
@@ -159,7 +159,7 @@ void ThumbHSL::notifySatChange(const unsigned i) {
   }
 }
 
-void ThumbHSL::notifyLightChange(const unsigned i) {
+void ThumbHSL::notifyLightChange(const int i) {
   if (i == cluster) {
     float l = model->getLight(cluster);
     int val = intround(SLIDER_RES * l);
@@ -184,7 +184,7 @@ void ThumbHSL::notifyLightChange(const unsigned i) {
   }
 }
 
-void ThumbHSL::notifyAlphaChange(const unsigned i) {
+void ThumbHSL::notifyAlphaChange(const int i) {
   //if (i == cluster) {
   //float a = model->getAlpha(cluster);
   //int val = static_cast<int>(255.0f*a);
