@@ -35,7 +35,7 @@ public:
    * @param model Cluster model. Caller retains ownership.
    * @param cluster Cluster number to which this thumbnail pertains.
    */
-  ThumbImage(wxWindow *parent, const unsigned int cluster);
+  ThumbImage(wxWindow *parent, const int cluster);
 
   /**
    * Set model.
@@ -47,8 +47,8 @@ public:
   virtual void notifyNumClustersChange();
   virtual void notifySaturationDecayChange();
   virtual void notifySaturationSoftnessChange();
-  virtual void notifyClusterChange(const unsigned int i);  
-  virtual void notifySatChange(const unsigned i);
+  virtual void notifyClusterChange(const int i);  
+  virtual void notifySatChange(const int i);
   
   /**
    * Handle paint event.
@@ -84,7 +84,7 @@ private:
   /**
    * Cluster number.
    */
-  unsigned int cluster;
+  int cluster;
 
   /**
    * Is thumbnail active? (in active state, even if cluster not selected,
