@@ -23,7 +23,7 @@ using namespace indii;
 
 ThumbPane::ThumbPane(wxWindow* parent) : wxScrolledWindow(parent),
     model(NULL) {
-  unsigned i;
+  int i;
   
   /* HSL thumbnails */
   ThumbHSL* thumb;
@@ -33,9 +33,7 @@ ThumbPane::ThumbPane(wxWindow* parent) : wxScrolledWindow(parent),
   }  
   
   /* add/remove thumbnail buttons */
-  #ifndef __WXGTK__
   gnome_scale_images(this->GetContentScaleFactor());
-  #endif
   #ifdef __WXMSW__
   /* wxMSW seems to create invisible, but functional, buttons when classic
    * theme is active -- just use text buttons instead */
@@ -72,7 +70,7 @@ ThumbPane::ThumbPane(wxWindow* parent) : wxScrolledWindow(parent),
 void ThumbPane::setModel(ClusterModel* model) {
   this->model = model;
   ignore();
-  for (unsigned i = 0; i < thumbs.size(); ++i) {
+  for (int i = 0; i < (int)thumbs.size(); ++i) {
     thumbs[i]->setModel(model);
   }
 
@@ -90,7 +88,7 @@ void ThumbPane::updateLayout() {
   const wxSize& thumbSize = thumbs[0]->GetSize();
   int cols = std::max(size.GetWidth() / (thumbSize.GetWidth() + 30), 1);
   
-  unsigned i;
+  int i;
   wxFlexGridSizer* sizer = new wxFlexGridSizer(cols);
   wxSizer* oldSizer;
   for (i = 0; i < 16; i++) {
