@@ -13,19 +13,13 @@
 #include "TintApp.hpp"
 
 #include "TintWindow.hpp"
-#include "../images/tint.hpp"
-#include "../../gui/Splash.hpp"
-
-#include "wx/splash.h"
 
 using namespace indii;
 
 INDII_IMPLEMENT_APP(TintApp)
 
 void TintApp::splash() {
-  tint_initialize_images();
-  wxSplashScreen* splash = new wxSplashScreen(Splash(_img_tint_splash),
-      wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_TIMEOUT, 5000, NULL, -1);
+  //
 }
 
 indii::Window* TintApp::open(const wxString& file) {
