@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 500 $
- * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
+ * $Rev$
+ * $Date$
  */
 #include "TintDocument.hpp"
 
@@ -29,11 +29,7 @@ TintDocument::TintDocument(wxWindow* parent, const wxString& path) :
 
   model->prepare();
   model->cluster();
-  model->lock();
-
-  model->unlock();
   watch(model);
-
   set(res, model);
 }
 
