@@ -231,7 +231,7 @@ void TintWindow::setModel(Model* model) {
   mixerPane->setModel(cmodel);
 }
 
-bool TintWindow::isShown(const unsigned i) {
+bool TintWindow::isShown(const int i) {
   /* pre-condition */
   assert (i < 4);
 
@@ -249,7 +249,7 @@ bool TintWindow::isShown(const unsigned i) {
   }
 }
 
-void TintWindow::show(const unsigned i, const bool show) {
+void TintWindow::show(const int i, const bool show) {
   /* pre-condition */
   assert (i < 4);
   
