@@ -69,8 +69,8 @@ public:
   virtual Document* open(const wxString& file);
   virtual void layoutDefault();
   virtual void setModel(Model* model);
-  virtual bool isShown(const unsigned i);
-  virtual void show(const unsigned i, const bool show);
+  virtual bool isShown(const int i);
+  virtual void show(const int i, const bool show);
 
 protected:
   virtual void initPanes();
