@@ -79,14 +79,14 @@ public:
    *
    * @return Number of clusters.
    */
-  unsigned getNumClusters();
+  int getNumClusters();
 
   /**
    * Set number of clusters.
    *
    * @param k Number of clusters.
    */
-  void setNumClusters(const unsigned k);
+  void setNumClusters(const int k);
 
   /**
    * Is cluster assignment hard?
@@ -114,14 +114,14 @@ public:
    *
    * @return Number of repetitions.
    */
-  unsigned getNumRepetitions();
+  int getNumRepetitions();
 
   /**
    * Set number of clusters.
    *
    * @param reps Number of repetitions.
    */
-  void setNumRepetitions(const unsigned reps);
+  void setNumRepetitions(const int reps);
 
   /**
    * Get saturation threshold.
@@ -142,14 +142,14 @@ public:
    *
    * @return Maximum pixels for clustering.
    */
-  unsigned getMaxPixels();
+  int getMaxPixels();
 
   /**
    * Set maximum pixels for clustering.
    *
    * @param n Maximum pixels for clustering.
    */
-  void setMaxPixels(const unsigned n);
+  void setMaxPixels(const int n);
 
   /**
    * Get saturation decay.
@@ -212,7 +212,7 @@ public:
    *
    * @param i Cluster number.
    */
-  bool isShown(const unsigned i);
+  bool isShown(const int i);
 
   /**
    * Show (or hide) cluster.
@@ -220,7 +220,7 @@ public:
    * @param i Cluster number.
    * @param on True to show cluster in colour, false for b&w.
    */
-  void show(const unsigned i, const bool on = true);
+  void show(const int i, const bool on = true);
 
   /**
    * Show (or hide) all clusters.
@@ -236,7 +236,7 @@ public:
    *
    * @return Colour representing given cluster.
    */
-  const wxColour& getColour(const unsigned i);
+  const wxColour& getColour(const int i);
 
   /**
    * Get cluster colour.
@@ -246,7 +246,7 @@ public:
    * @param g Green value.
    * @param b Blue value.
    */
-  void getColour(const unsigned i, float* r, float* g, float* b);
+  void getColour(const int i, float* r, float* g, float* b);
   
   /**
    * Set cluster colour.
@@ -254,7 +254,7 @@ public:
    * @param i Cluster number.
    * @param col Cluster colour.
    */
-  void setColour(const unsigned i, const wxColour& col);
+  void setColour(const int i, const wxColour& col);
 
   /**
    * Set cluster colour.
@@ -264,7 +264,7 @@ public:
    * @param g Green value.
    * @param b Blue value.
    */
-  void setColour(const unsigned i, const float r, const float g, const float b);
+  void setColour(const int i, const float r, const float g, const float b);
 
   /**
    * Get cluster hue rotation.
@@ -273,7 +273,7 @@ public:
    *
    * @return Hue rotation of given cluster.
    */
-  float getHue(const unsigned i);
+  float getHue(const int i);
 
   /**
    * Set cluster hue rotation.
@@ -281,7 +281,7 @@ public:
    * @param i Cluster number.
    * @param x Hue rotation to set.
    */
-  void setHue(const unsigned i, const float x);
+  void setHue(const int i, const float x);
 
   /**
    * Get cluster saturation adjustment.
@@ -290,7 +290,7 @@ public:
    *
    * @return Saturation adjustment of given cluster.
    */
-  float getSat(const unsigned i);
+  float getSat(const int i);
 
   /**
    * Set cluster saturation adjustment.
@@ -298,7 +298,7 @@ public:
    * @param i Cluster number.
    * @param x Saturation adjustment to set.
    */
-  void setSat(const unsigned i, const float x);
+  void setSat(const int i, const float x);
 
   /**
    * Does cluster have any saturation?
@@ -308,7 +308,7 @@ public:
    * @return True if saturation of cluster @p i is significant (i.e. does not
    * round to grey), false otherwise.
    */
-  bool hasSat(const unsigned i);
+  bool hasSat(const int i);
 
   /**
    * Get cluster lightness adjustment.
@@ -317,7 +317,7 @@ public:
    *
    * @return Lightness adjustment of given cluster.
    */
-  float getLight(const unsigned i);
+  float getLight(const int i);
 
   /**
    * Set cluster lightness adjustment.
@@ -325,7 +325,7 @@ public:
    * @param i Cluster number.
    * @param x Lightness adjustment to set.
    */
-  void setLight(const unsigned i, const float x);
+  void setLight(const int i, const float x);
 
   /**
    * Does cluster have any light?
@@ -335,7 +335,7 @@ public:
    * @return True if lightness of cluster @p i is significant (i.e. does not
    * round to black), false otherwise.
    */
-  bool hasLight(const unsigned i);
+  bool hasLight(const int i);
 
   /**
    * Get cluster alpha adjustment.
@@ -344,7 +344,7 @@ public:
    *
    * @return Alpha adjustment of given cluster.
    */
-  float getAlpha(const unsigned i);
+  float getAlpha(const int i);
 
   /**
    * Set cluster alpha adjustment.
@@ -352,7 +352,7 @@ public:
    * @param i Cluster number.
    * @param x Alpha adjustment to set.
    */
-  void setAlpha(const unsigned i, const float x);
+  void setAlpha(const int i, const float x);
 
   /**
    * Calculate alpha channel of subimage for particular cluster.
@@ -362,7 +362,7 @@ public:
    * @param scale Inverse scale of image.
    * @param[out] c Output channel.
    */
-  void calcAlpha(const unsigned i, const wxRect& rect, const float scale,
+  void calcAlpha(const int i, const wxRect& rect, const float scale,
       channel& c);
 
   /**
@@ -375,7 +375,7 @@ public:
    *
    * @return Mask for the given cluster and region.
    */
-  sparse_mask calcMask(const unsigned i, const wxRect& rect, const float scale);
+  sparse_mask calcMask(const int i, const wxRect& rect, const float scale);
 
   /**
    * Prepare data set for clustering.
@@ -408,7 +408,7 @@ private:
   /**
    * Number of clusters.
    */
-  unsigned k;
+  int k;
 
   /**
    * Cluster hardness.
@@ -418,7 +418,7 @@ private:
   /**
    * Number of repetitions.
    */
-  unsigned reps;
+  int reps;
 
   /**
    * Saturation threshold.
@@ -428,7 +428,7 @@ private:
   /**
    * Maximum number of pixels for clustering.
    */
-  unsigned maxPixels;
+  int maxPixels;
 
   /**
    * Saturation decay.
@@ -497,7 +497,7 @@ private:
 };
 }
 
-inline unsigned indii::ClusterModel::getNumClusters() {
+inline int indii::ClusterModel::getNumClusters() {
   return k;
 }
 
@@ -509,7 +509,7 @@ inline float indii::ClusterModel::getHard() {
   return hard;
 }
 
-inline unsigned indii::ClusterModel::getNumRepetitions() {
+inline int indii::ClusterModel::getNumRepetitions() {
   return reps;
 }
 
@@ -517,7 +517,7 @@ inline float indii::ClusterModel::getSaturationThreshold() {
   return saturationThreshold;
 }
 
-inline unsigned indii::ClusterModel::getMaxPixels() {
+inline int indii::ClusterModel::getMaxPixels() {
   return maxPixels;
 }
 
@@ -537,18 +537,18 @@ inline float indii::ClusterModel::getCentroidSoftness() {
   return centroidSoftness;
 }
 
-inline bool indii::ClusterModel::isShown(const unsigned i) {
+inline bool indii::ClusterModel::isShown(const int i) {
   return hasSat(i);
 }
 
-inline const wxColour& indii::ClusterModel::getColour(const unsigned i) {
+inline const wxColour& indii::ClusterModel::getColour(const int i) {
   /* pre-condition */
   assert(i < k);
 
   return colours[i];
 }
 
-inline void indii::ClusterModel::getColour(const unsigned i, float* r, float* g, float* b) {
+inline void indii::ClusterModel::getColour(const int i, float* r, float* g, float* b) {
   /* pre-condition */
   assert(i < k);
   
@@ -557,42 +557,42 @@ inline void indii::ClusterModel::getColour(const unsigned i, float* r, float* g,
   *b = mus[i][2];
 }
 
-inline float indii::ClusterModel::getHue(const unsigned i) {
+inline float indii::ClusterModel::getHue(const int i) {
   /* pre-condition */
   assert(i < k);
 
   return hues[i];
 }
 
-inline float indii::ClusterModel::getSat(const unsigned i) {
+inline float indii::ClusterModel::getSat(const int i) {
   /* pre-condition */
   assert(i < k);
 
   return sats[i];
 }
 
-inline float indii::ClusterModel::getLight(const unsigned i) {
+inline float indii::ClusterModel::getLight(const int i) {
   /* pre-condition */
   assert(i < k);
 
   return lights[i];
 }
 
-inline float indii::ClusterModel::getAlpha(const unsigned i) {
+inline float indii::ClusterModel::getAlpha(const int i) {
   /* pre-condition */
   assert(i < k);
 
   return alphas[i];
 }
 
-inline bool indii::ClusterModel::hasLight(const unsigned i) {
+inline bool indii::ClusterModel::hasLight(const int i) {
   /* pre-condition */
   assert(i < k);
 
   return lights[i] > -1.0f;
 }
 
-inline bool indii::ClusterModel::hasSat(const unsigned i) {
+inline bool indii::ClusterModel::hasSat(const int i) {
   /* pre-condition */
   assert(i < k);
 
